==> haskell-iproute-1.7.8-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-iproute.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: iproute
version: 1.7.8
id: iproute-1.7.8-73rJVhaJJ3c1mXeX3YZQlY
key: iproute-1.7.8-73rJVhaJJ3c1mXeX3YZQlY
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: http://www.mew.org/~kazu/proj/iproute/
synopsis: IP Routing Table
description:
    IP Routing Table is a tree of IP ranges
    to search one of them on the longest
    match base. It is a kind of TRIE with one
    way branching removed. Both IPv4 and IPv6
    are supported.
category: Algorithms, Network
abi: 6fce81e240dfcf3edcac4f6bf7bba4ef
exposed: True
exposed-modules:
    Data.IP Data.IP.Internal Data.IP.RouteTable
    Data.IP.RouteTable.Internal
hidden-modules: Data.IP.Addr Data.IP.Mask Data.IP.Op Data.IP.Range
import-dirs: /usr/lib/ghc-8.6.5/site-local/iproute-1.7.8
library-dirs: /usr/lib/ghc-8.6.5/site-local/iproute-1.7.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/iproute-1.7.8
hs-libraries: HSiproute-1.7.8-73rJVhaJJ3c1mXeX3YZQlY
depends:
    appar-0.1.8-GEXCW6eRsA87u3FkbnD06R base-4.12.0.0
    byteorder-1.0.4-IVStE0plZAH4UpHo5zwztw containers-0.6.0.1
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
haddock-interfaces: /usr/share/doc/haskell-iproute/html/iproute.haddock
haddock-html: /usr/share/doc/haskell-iproute/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-iproute-1.7.8-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-iproute.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: iproute
version: 1.7.8
id: iproute-1.7.8-8ziugmLGBLULYq67vXuTsH
key: iproute-1.7.8-8ziugmLGBLULYq67vXuTsH
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: http://www.mew.org/~kazu/proj/iproute/
synopsis: IP Routing Table
description:
    IP Routing Table is a tree of IP ranges
    to search one of them on the longest
    match base. It is a kind of TRIE with one
    way branching removed. Both IPv4 and IPv6
    are supported.
category: Algorithms, Network
abi: dcd0d54eece4fe6ff8c32a3cde791de8
exposed: True
exposed-modules:
    Data.IP Data.IP.Internal Data.IP.RouteTable
    Data.IP.RouteTable.Internal
hidden-modules: Data.IP.Addr Data.IP.Mask Data.IP.Op Data.IP.Range
import-dirs: /usr/lib/ghc-8.6.5/site-local/iproute-1.7.8
library-dirs: /usr/lib/ghc-8.6.5/site-local/iproute-1.7.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/iproute-1.7.8
hs-libraries: HSiproute-1.7.8-8ziugmLGBLULYq67vXuTsH
depends:
    appar-0.1.8-GEXCW6eRsA87u3FkbnD06R base-4.12.0.0
    byteorder-1.0.4-IVStE0plZAH4UpHo5zwztw containers-0.6.0.1
    network-2.8.0.0-LvSlvEKiGr81Yl4BCXERfa
haddock-interfaces: /usr/share/doc/haskell-iproute/html/iproute.haddock
haddock-html: /usr/share/doc/haskell-iproute/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
